@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -107,7 +107,7 @@ QHash<Utils::AppsType, Utils::importExportParameters> SelectionTypeDialog::store
     return mSelectionTreeWidget->storedType();
 }
 
-QString SelectionTypeDialog::exportedFileInfo()
+QString SelectionTypeDialog::exportedFileInfo() const
 {
     return mSelectionTreeWidget->exportedFileInfo();
 }
